@@ -2,7 +2,7 @@ eplusr_option(verbose_info = FALSE)
 
 # IDD {{{
 test_that("IDD", {
-    expect_is(idd <- EpwIdd$new(system.file("extdata/epw.idd", package = "eplusr")), "Idd")
+    expect_s3_class(idd <- EpwIdd$new(system.file("extdata/epw.idd", package = "eplusr")), "Idd")
     expect_output(idd$print())
 })
 # }}}
@@ -11,17 +11,17 @@ test_that("IDD", {
 test_that("Meta info", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
-    expect_is(epw <- read_epw(path_epw), "Epw")
+    expect_s3_class(epw <- read_epw(path_epw), "Epw")
 
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
 
     # can update the path after saved
     expect_equal(epw$path(), normalizePath(path_epw))
 
     # can get definition
-    expect_is(epw$definition("LOCATION"), "IddObject")
+    expect_s3_class(epw$definition("LOCATION"), "IddObject")
 })
 # }}}
 
@@ -29,7 +29,7 @@ test_that("Meta info", {
 test_that("Header getter and setter", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
     expect_silent(epw <- Epw$new(path_epw))
 
@@ -55,18 +55,18 @@ test_that("Header getter and setter", {
     # }}}
 
     # $design_condition() {{{
-    expect_is(epw$design_condition(), "list")
+    expect_type(epw$design_condition(), "list")
     expect_equal(names(epw$design_condition()), c("source", "heating", "cooling", "extremes"))
     # }}}
 
     # $typical_extreme_period() {{{
-    expect_is(epw$typical_extreme_period(), "data.table")
+    expect_s3_class(epw$typical_extreme_period(), "data.table")
     expect_equal(names(epw$typical_extreme_period()), c("index", "name", "type", "start_day", "end_day"))
     expect_equal(nrow(epw$typical_extreme_period()), 6L)
     # }}}
 
     # $ground_temperature {{{
-    expect_is(epw$ground_temperature(), "data.table")
+    expect_s3_class(epw$ground_temperature(), "data.table")
     expect_equal(names(epw$ground_temperature()), c(
         "index",              "depth",
         "soil_conductivity",  "soil_density",  "soil_specific_heat",
@@ -79,7 +79,7 @@ test_that("Header getter and setter", {
     # }}}
 
     # $ground_temperature {{{
-    expect_is(epw$ground_temperature(), "data.table")
+    expect_s3_class(epw$ground_temperature(), "data.table")
     expect_equal(names(epw$ground_temperature()), c(
         "index",              "depth",
         "soil_conductivity",  "soil_density",  "soil_specific_heat",
@@ -93,16 +93,16 @@ test_that("Header getter and setter", {
 
     # $holiday {{{
     expect_silent(epw <- Epw$new(path_epw))
-    expect_is(epw$holiday(), "list")
+    expect_type(epw$holiday(), "list")
     expect_equal(names(epw$holiday()), c("leapyear", "dst", "holiday"))
 
     # leapyear
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
     expect_equal(epw$holiday()$leapyear, FALSE)
     expect_error(epw$holiday(TRUE), class = "eplusr_error_epw_header")
 
     # change to leapyear
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
     expect_warning(d <- epw$data(1, start_year = 2016, align_wday = FALSE))
     feb29 <- d[month == 2 & day == 28][, day := 29L]
     d <- rbindlist(list(d, feb29))[order(month, day)]
@@ -112,30 +112,30 @@ test_that("Header getter and setter", {
     expect_error(epw$holiday(FALSE))
 
     # dst
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
     expect_equal(epw$holiday(dst = c(1, 2))$dst, epw_date(1:2))
     expect_equal(epw$holiday(dst = c(as.Date("2008-01-01"), as.Date("2008-02-01")))$dst, epw_date(c("Jan 01", "Feb 01")))
 
     # holiday
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(hol <- epw$holiday(holiday = list(name = "New Year", day = "Jan 01")), "list")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_type(hol <- epw$holiday(holiday = list(name = "New Year", day = "Jan 01")), "list")
     expect_equal(hol$holiday,
         data.table(index = 1L, name = "New Year", day = epw_date("1/1"))
     )
 
     # can restore the original data
     expect_error(epw$holiday(holiday = list(name = "New Year", day = "Jan 41")))
-    expect_is(hol <- epw$holiday(), "list")
+    expect_type(hol <- epw$holiday(), "list")
     expect_equal(hol$holiday,
         data.table(index = 1L, name = "New Year", day = epw_date("1/1"))
     )
     # }}}
 
     # $comment() {{{
-    expect_is(epw$comment1(), "character")
+    expect_type(epw$comment1(), "character")
     expect_equal(epw$comment1("comment1"), "comment1")
     expect_equal(epw$comment1(), "comment1")
-    expect_is(epw$comment2(), "character")
+    expect_type(epw$comment2(), "character")
     expect_equal(epw$comment2("comment2"), "comment2")
     expect_equal(epw$comment2(), "comment2")
     expect_null(epw$comment2(""))
@@ -153,8 +153,8 @@ test_that("Header getter and setter", {
     # }}}
 
     # $period {{{
-    expect_is(epw$period(), "data.table")
-    expect_is(epw$period(1), "data.table")
+    expect_s3_class(epw$period(), "data.table")
+    expect_s3_class(epw$period(1), "data.table")
     expect_error(epw$period(2), class = "eplusr_error_epw_data_period_index")
     expect_equal(epw$period(1, name = "test")$name, "test")
     expect_error(epw$period(1, start_day_of_week = "test"), class = "eplusr_error_validity_check")
@@ -171,19 +171,19 @@ test_that("Header getter and setter", {
 test_that("Constant data", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
     expect_silent(epw <- Epw$new(path_epw))
 
-    expect_is(epw$missing_code(), "list")
+    expect_type(epw$missing_code(), "list")
     expect_equal(length(epw$missing_code()), 29L)
-    expect_is(epw$initial_missing_value(), "list")
+    expect_type(epw$initial_missing_value(), "list")
     expect_equal(length(epw$initial_missing_value()), 14L)
-    expect_is(epw$range_exist(), "list")
+    expect_type(epw$range_exist(), "list")
     expect_equal(length(epw$range_exist()), 28L)
-    expect_is(epw$range_valid(), "list")
+    expect_type(epw$range_valid(), "list")
     expect_equal(length(epw$range_valid()), 28L)
-    expect_is(epw$fill_action(), "list")
+    expect_type(epw$fill_action(), "list")
     expect_equal(names(epw$fill_action()), c("use_previous", "use_zero"))
 })
 # }}}
@@ -192,10 +192,10 @@ test_that("Constant data", {
 test_that("$save() & $is_unsaved()", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(d_ori <- epw$data(), "data.table")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(d_ori <- epw$data(), "data.table")
 
     # $is_unsaved() {{{
     expect_false(epw$is_unsaved())
@@ -204,10 +204,10 @@ test_that("$save() & $is_unsaved()", {
     # $save() {{{
     expect_error(epw$save(".idf"))
     unlink(file.path(tempdir(), "test_save.epw"), force = TRUE)
-    expect_is(epw$save(file.path(tempdir(), "test_save.epw")), "character")
+    expect_type(epw$save(file.path(tempdir(), "test_save.epw")), "character")
     expect_error(epw$save(file.path(tempdir(), "test_save.epw")), class = "eplusr_error")
-    expect_is(epw$save(overwrite = TRUE), "character")
-    expect_is(epw1 <- Epw$new(file.path(tempdir(), "test_save.epw")), "Epw")
+    expect_type(epw$save(overwrite = TRUE), "character")
+    expect_s3_class(epw1 <- Epw$new(file.path(tempdir(), "test_save.epw")), "Epw")
     expect_equal(epw1$data(), d_ori)
     # }}}
 })
@@ -217,9 +217,9 @@ test_that("$save() & $is_unsaved()", {
 test_that("Data Getter", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
 
     # $data() {{{
     # can get weather data
@@ -280,9 +280,9 @@ test_that("Data Getter", {
 test_that("Data Tagger", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
 
     # $make_na() {{{
     expect_true({
@@ -303,7 +303,7 @@ test_that("Data Tagger", {
     # }}}
 
     # $add_unit() & $drop_unit() {{{
-    expect_is(class = "units",
+    expect_s3_class(class = "units",
         {
             epw$add_unit()
             rad <- epw$data()$direct_normal_radiation
@@ -313,13 +313,13 @@ test_that("Data Tagger", {
     expect_equal(units(rad)$denominator, c("m", "m"))
     expect_message(with_verbose(epw$add_unit()), "already")
 
-    expect_is(epw$drop_unit()$data()$dry_bulb_temperature, "numeric")
+    expect_type(epw$drop_unit()$data()$dry_bulb_temperature, "double")
     expect_message(with_verbose(epw$drop_unit()), "already")
     # }}}
 
     # $purge() {{{
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(epw$purge(), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw$purge(), "Epw")
     epw$.__enclos_env__$private$m_data <- rbindlist(list(get_priv_env(epw)$m_data, epw$data()))
     expect_message(with_verbose(epw$purge()))
     # }}}
@@ -330,12 +330,12 @@ test_that("Data Tagger", {
 test_that("Data Setter", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
-    expect_is(epw <- read_epw(path_epw), "Epw")
+    expect_s3_class(epw <- read_epw(path_epw), "Epw")
 
     # $set() {{{
-    expect_is(d <- epw$data(), "data.table")
+    expect_s3_class(d <- epw$data(start_year = 2017), "data.table")
     expect_output(with_verbose(epw$set(d, realyear = TRUE)))
     expect_equal(epw$period(),
         data.table(index = 1L, name = "Data", start_day_of_week = "Sunday",
@@ -343,11 +343,11 @@ test_that("Data Setter", {
         )
     )
 
-    expect_warning(epw$set(d, realyear = TRUE, start_day_of_week = "Monday"))
+    expect_warning(expect_warning(epw$set(d, realyear = TRUE, start_day_of_week = "Monday")))
     expect_warning(epw$set(d, realyear = TRUE))
     expect_equal(epw$period()$start_day_of_week, "Sunday")
 
-    expect_is(epw$set(d[1:48]), "Epw")
+    expect_s3_class(epw$set(d[1:48]), "Epw")
     expect_equal(epw$period(),
         data.table(index = 1L, name = "Data", start_day_of_week = "Sunday",
             start_day = epw_date("1/1", F), end_day = epw_date("1/2", F)
@@ -357,7 +357,7 @@ test_that("Data Setter", {
 
     # can remove extra columns
     set(d, NULL, "extra_column", 1)
-    expect_is(epw$set(d), "Epw")
+    expect_s3_class(epw$set(d), "Epw")
     expect_equal(ncol(epw$data()), 36)
 
     expect_error({
@@ -375,7 +375,7 @@ test_that("Data Setter", {
     # }}}
 
     # $add() {{{
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
 
     expect_error(epw$add(epw$data()), class = "eplusr_error_parse_epw")
 
@@ -389,7 +389,7 @@ test_that("Data Setter", {
 
     # after N
     expect_warning(d <- epw$data(start_year = 2014, align_wday = FALSE))
-    expect_is(epw$add(d, after = 10, realyear = TRUE), "Epw")
+    expect_s3_class(epw$add(d, after = 10, realyear = TRUE), "Epw")
     expect_equal(epw$period()$name, c("Data1", "Data", "Data2"))
     expect_equal(lubridate::year(epw$data(3, align_wday = FALSE)$datetime[1]), 2014)
     expect_equal(get_priv_env(epw)$m_log$matched,
@@ -398,68 +398,68 @@ test_that("Data Setter", {
 
     # between
     expect_warning(d <- epw$data(1, start_year = 2013, align_wday = FALSE))
-    expect_is(epw$add(d, after = 2, realyear = TRUE), "Epw")
+    expect_s3_class(epw$add(d, after = 2, realyear = TRUE), "Epw")
     expect_equal(lubridate::year(epw$data(3, align_wday = FALSE)$datetime[1]), 2013)
     expect_equal(get_priv_env(epw)$m_log$matched,
         data.table(index = 1:4, row = c(1L, 8761L, 17521L, 26281L), num = rep(8760L, 4))
     )
 
     # unit + no unit
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(d <- epw$data(start_year = 2017), "data.table")
-    expect_is(epw$add_unit(), "Epw")
-    expect_is(epw$add(d, realyear = TRUE), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(d <- epw$data(start_year = 2017), "data.table")
+    expect_s3_class(epw$add_unit(), "Epw")
+    expect_s3_class(epw$add(d, realyear = TRUE), "Epw")
     expect_warning(u <- units(epw$data()$liquid_precip_rate)$numerator)
     expect_equal(u, "h")
 
     # unit + unit
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(epw$add_unit(), "Epw")
-    expect_is(d <- epw$data(start_year = 2017), "data.table")
-    expect_is(epw$add(d, realyear = TRUE), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw$add_unit(), "Epw")
+    expect_s3_class(d <- epw$data(start_year = 2017), "data.table")
+    expect_s3_class(epw$add(d, realyear = TRUE), "Epw")
     expect_warning(u <- units(epw$data()$liquid_precip_rate)$numerator)
     expect_equal(u, "h")
 
     # no unit + unit
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(epw$add_unit(), "Epw")
-    expect_is(d <- epw$data(start_year = 2017), "data.table")
-    expect_is(epw$drop_unit(), "Epw")
-    expect_is(epw$add(d, realyear = TRUE), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw$add_unit(), "Epw")
+    expect_s3_class(d <- epw$data(start_year = 2017), "data.table")
+    expect_s3_class(epw$drop_unit(), "Epw")
+    expect_s3_class(epw$add(d, realyear = TRUE), "Epw")
     expect_warning(u <- epw$data()$liquid_precip_rate)
-    expect_is(u, "numeric")
+    expect_type(u, "double")
 
     # no na + na
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(epw$make_na(TRUE, TRUE), "Epw")
-    expect_is(d <- epw$data(start_year = 2017), "data.table")
-    expect_is(epw$fill_abnormal(TRUE, TRUE), "Epw")
-    expect_is(epw$add(d, realyear = TRUE), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw$make_na(TRUE, TRUE), "Epw")
+    expect_s3_class(d <- epw$data(start_year = 2017), "data.table")
+    expect_s3_class(epw$fill_abnormal(TRUE, TRUE), "Epw")
+    expect_s3_class(epw$add(d, realyear = TRUE), "Epw")
     expect_true(all(!is.na(epw$abnormal_data(cols = "albedo", keep_all = FALSE, type = "missing")$albedo)))
 
     # na + no na
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(d <- epw$data(start_year = 2017), "data.table")
-    expect_is(epw$make_na(TRUE, TRUE), "Epw")
-    expect_is(epw$add(d, realyear = TRUE), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(d <- epw$data(start_year = 2017), "data.table")
+    expect_s3_class(epw$make_na(TRUE, TRUE), "Epw")
+    expect_s3_class(epw$add(d, realyear = TRUE), "Epw")
     expect_true(all(is.na(epw$abnormal_data(cols = "albedo", keep_all = FALSE, type = "missing")$albedo)))
 
     # can remove extra columns
-    expect_is(epw <- Epw$new(path_epw), "Epw")
-    expect_is(d <- epw$data(start_year = 2017), "data.table")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(d <- epw$data(start_year = 2017), "data.table")
     set(d, NULL, "extra_column", 1)
-    expect_is(epw$add(d, realyear = TRUE), "Epw")
+    expect_s3_class(epw$add(d, realyear = TRUE), "Epw")
     expect_warning(d <- epw$data())
     expect_equal(ncol(d), 36)
     # }}}
 
     # $del() {{{
-    expect_is(epw <- Epw$new(path_epw), "Epw")
+    expect_s3_class(epw <- Epw$new(path_epw), "Epw")
 
     expect_error(epw$del())
     expect_error(epw$del(1))
 
-    expect_is(epw$add(epw$data(start_year = 2017), realyear = TRUE), "Epw")
+    expect_s3_class(epw$add(epw$data(start_year = 2017), realyear = TRUE), "Epw")
     expect_message(with_verbose(epw$del(1)))
     # }}}
 })
@@ -469,8 +469,8 @@ test_that("Data Setter", {
 test_that("$clone()", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
-    expect_is(epw1 <- Epw$new(path_epw), "Epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    expect_s3_class(epw1 <- Epw$new(path_epw), "Epw")
 
     epw2 <- epw1$clone()
     epw2$period(1, name = "Data2")
@@ -483,7 +483,7 @@ test_that("$clone()", {
 test_that("$print()", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
     expect_silent(epw <- Epw$new(path_epw))
 
@@ -497,11 +497,11 @@ test_that("$print()", {
 test_that("str.Epw & format.Epw", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
     expect_silent(epw <- Epw$new(path_epw))
     expect_output(str(epw))
-    expect_is(format(epw), "character")
+    expect_type(format(epw), "character")
 })
 # }}}
 
@@ -509,7 +509,7 @@ test_that("str.Epw & format.Epw", {
 test_that("==.Epw & !=.Epw", {
     skip_on_cran()
 
-    path_epw <- file.path(eplus_config(8.8)$dir, "WeatherData", "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
     expect_silent(epw <- Epw$new(path_epw))
 
@@ -535,3 +535,5 @@ test_that("download_weather()", {
     )})
 })
 # }}}
+
+# vim: set fdm=marker:
